/*_________________________________________________________________________________

                             S T R E A M   R E A D E R   /   W R I T E R   D E M O
                                                
                                            Originally Created 4/22/2013
                                                        Ron Kessler
                                                    VS 2015 Version
 _________________________________________________________________________________

 Last updated 1/14/2016

 FEATURES: 
    1.  Shows how to read/write to a sequential text file
    2.  Lets user create file when program first loads
    3.  Items can be added/removed from list box
    4.  Items in list box can be saved to disk
    5.  Shows how to use Foreach loop with list box items
    6.  Uses structured error handling
 
*/

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

//---be sure to add this for Stream Classes
using System.IO;

namespace Using_Streams
{
    public partial class frmMain : Form
    {

        //---class-level variables
        //string diskFile = "..\\..\\inventory.txt";        //our datafile  remember to include the ..\\ bit!

        //string diskFile = @"..\..\inventory.txt";         //by using the @ sign, C# will read our string without thinking \\ is an escape sequence!

        const String msgTitle = "Ron's Train Store";

        //--you can store the diskfile path in the Resources file. Then get it this way:
        string diskFile = Using_Streams.Properties.Resources.MyInventoryFile;

        StreamReader sr;        //define it here without instaniating
        StreamWriter sw;


        public frmMain ()
           
        {
            InitializeComponent();           
        }

     


        private void frmMain_Load(object sender, EventArgs e)
        {
            DoReload();
        }

       
         private void DoReload()

        {
                       
            //---if file does not exist lets create it for them if they want to.
            if (File.Exists(diskFile) == false)
            {
               if (MessageBox.Show("Cannot locate inventory file. Shall I create it?",msgTitle, 
                MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.Yes)
                                   
                    File.Create(diskFile);
                else
                    txtNewItem.Focus();      //or you could exit here:  this.close();
               
            }
            else
            {
                try
                {
                    lstItems.Items.Clear();              //no duplicates
                    sr = new StreamReader(diskFile);
                    string dataFromFile;
                    {
                        while (sr.Peek() != -1)
                        {
                            dataFromFile = sr.ReadLine();
                            lstItems.Items.Add(dataFromFile);

                        }

                    }
                }
                catch (Exception e)
                {

                    MessageBox.Show("An error occurred while reading...." + e.Message,
                        msgTitle, MessageBoxButtons.OK, MessageBoxIcon.Error);
                    this.Close();
                }
                finally
                {
                    sr.Close();         //make sure to always close the reader
                                   
                }
            }
             
        }

        private void btnReload_Click(object sender, EventArgs e)
        {
            DoReload();
        }

     
     
        private void btnAdd_Click(object sender, EventArgs e)
        {
            string myNewItem = txtNewItem.Text.Trim();
            lstItems.Items.Add(myNewItem);
        }

                private void btnSave_Click(object sender, EventArgs e)
        {

            try
            {
                sw = new StreamWriter(diskFile, false);   //false means do not append data!

                    foreach (string myItem in lstItems.Items)
                    {
                        sw.WriteLine(myItem);
                    }
                MessageBox.Show("Your data has been updated.",
                    msgTitle, MessageBoxButtons.OK, MessageBoxIcon.Information);
            }

            catch (Exception ex)
            {
                MessageBox.Show("I could not save your changes." + ex.Message,
                    msgTitle, MessageBoxButtons.OK, MessageBoxIcon.Error);

            }
            finally
            {
                    sw.Close();             //always do this
                               
            }
            
        }
        private void btnClear_Click (object sender, EventArgs e)
            {
            lstItems.Items.Clear();
            }

        private void btnDelete_Click (object sender, EventArgs e)
            {

            if (MessageBox.Show("Are you sure you want to delete " + lstItems.SelectedItem + "?", msgTitle,
                  MessageBoxButtons.YesNo, MessageBoxIcon.Question) == System.Windows.Forms.DialogResult.Yes)
                    
                lstItems.Items.Remove(lstItems.SelectedItem);
            else
                txtNewItem.Focus();
          
            }


        private void btnExit_Click (object sender, EventArgs e)
            {
            this.Close();
            }
  
    }

}